# Table of Contents

- [strict-filtering](<./strict-filtering.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Strict Filtering](<./Strict-Filtering.md>)
  - [Filtering on relations without strict filtering](<./Strict-Filtering/Filtering-on-relations-without-strict-filtering.md>)
  - [Filtering on relation fields without strict filtering](<./Strict-Filtering/Filtering-on-relation-fields-without-strict-filtering.md>)
  - [Strict filtering for filters on relations](<./Strict-Filtering/Strict-filtering-for-filters-on-relations.md>)
  - [Strict Filtering with filters for fields on relations](<./Strict-Filtering/Strict-Filtering-with-filters-for-fields-on-relations.md>)
  - [Was this page helpful?](<./Strict-Filtering/Was-this-page-helpful.md>)
